==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/oesig_help/__openerp__.py <==
#-*- encoding: utf-8 -*-
##############################################################################
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

{
    "name" : "OESIG Help",
    'version': '7.0.21.12.14',
    "description" : '''
    OpenERP Help
    ''',
    "author" : "Shine IT",
    "website" : "http://www.siginformatica.com.br",
    "depends" : ['base'],
    "data" : ['oesig_help_view.xml'],
    "installable" : True,
    "web": True,
    "js":["static/src/js/oesig_help.js"],
    "css":["static/src/css/oesig_help.css"],
    "qweb":[
        "static/src/xml/*.xml",
    ],
    "images":['images/share_wizard.jpeg'],
    "certificate" : "",
    "category":'Generic Modules/Others'
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/oesig_help/__openerp__.py <==
#-*- encoding: utf-8 -*-
##############################################################################
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

{
    "name" : "OESIG Help",
    'version': '7.0.2310.2',
    "description" : '''
    OpenERP Help
    ''',
    "author" : "Shine IT",
    "website" : "http://www.siginformatica.com.br",
    "depends" : ['base'],
    "data" : ['oesig_help_view.xml'],
    "installable" : True,
    "web": True,
    "js":["static/src/js/oesig_help.js"],
    "css":["static/src/css/oesig_help.css"],
    "qweb":[
        "static/src/xml/*.xml",
    ],
    "images":['images/share_wizard.jpeg'],
    "certificate" : "",
    "category":'Generic Modules/Others'
}
